.. :changelog:

History
-------

0.3.8(2014-1-27)
++++++++++++++++++
* You can now remove entities from groups

0.3.5(2014-1-27)
++++++++++++++++++
* Groups now return empty list if there is no group of that name

0.3.4(2014-1-26)
++++++++++++++++++
* Updated usage documentation to fix typo
* Added partial (subset) component selection

0.3.3(2014-1-26)
++++++++++++++++++
* Updated README with GitHub and PyPI links
* Systems can now be removed
* Entities can now be removed
* Entities will now check if they are alive or else raise an exception

0.3.2(2014-1-26)
++++++++++++++++++
* Added API documentation

0.3.1(2014-1-25)
++++++++++++++++++
* Realized I already had an installation and usage section

0.3.0(2014-1-25)
++++++++++++++++++
* Added usage documentation
* Fixed capitalization in tests

0.2.2(2014-1-25)
++++++++++++++++++
* Syntax error!

0.2.1 (2014-1-25)
++++++++++++++++++
* Realized I was even doing that wrong - looked at Facebook's tornado to figure it out

0.2.0 (2014-1-25)
++++++++++++++++++

* Forgot a requirement for Travis-CI

0.1.0 (2014-1-25)
++++++++++++++++++

* Added simple entity component system
* First release on PyPI.
